summaryrefslogtreecommitdiffstats
path: root/ksmserver/server.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksmserver/server.cpp')
-rw-r--r--ksmserver/server.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/ksmserver/server.cpp b/ksmserver/server.cpp
index ac4ef0e28..91cfb7544 100644
--- a/ksmserver/server.cpp
+++ b/ksmserver/server.cpp
@@ -911,9 +911,9 @@ bool KSMServer::isWM( const TQString& program ) const
{
// KWin relies on ksmserver's special treatment in phase1,
// therefore make sure it's recognized even if ksmserver
// was initially started with different WM, and kwin replaced
// it later
- return ((program == wm) || (program == "kwin"));
+ return ((program == wm) || (program == "twin"));
}
bool KSMServer::isCM( const KSMClient* client ) const
@@ -911,9 +911,9 @@ bool KSMServer::isWM( const TQString& program ) const
// KWin relies on ksmserver's special treatment in phase1,
// therefore make sure it's recognized even if ksmserver
- // was initially started with different WM, and kwin replaced
+ // was initially started with different WM, and twin replaced
// it later